@@ -5,6 +5,7 @@ import (
 	"context"
 	"crypto/sha256"
 	"encoding/hex"
+	"errors"
 	"fmt"
 	"io"
 	"os"
@@ -33,6 +34,7 @@ var (
 // Plugin contains the plugin properties
 type Plugin struct {
 	Shortname        string
+	Shortdesc        string
 	Binary           string
 	Releases         []Release `toml:"Release"`
 	MagicCookieValue string
@@ -152,37 +154,65 @@ func (p *Plugin) LookUpLatestVersion() string {
 }
 
 // Install installs the plugin of the given version
-func (p *Plugin) Install(ctx context.Context, config config.IConfig, fs afero.Fs, version string, baseURL string) error {
+func (p *Plugin) Install(ctx context.Context, cfg config.IConfig, fs afero.Fs, version string, baseURL string) error {
 	spinner := ansi.StartNewSpinner(ansi.Faint(fmt.Sprintf("installing '%s' v%s...", p.Shortname, version)), os.Stdout)
 
-	apiKey, err := config.GetProfile().GetAPIKey(false)
+	apiKey, err := cfg.GetProfile().GetAPIKey(false)
 
 	if err != nil {
 		ansi.StopSpinner(spinner, ansi.Faint(fmt.Sprintf("could not install plugin '%s': missing API key", p.Shortname)), os.Stdout)
 		return err
 	}
 
-	pluginData, err := requests.GetPluginData(ctx, baseURL, stripe.APIVersion, apiKey, config.GetProfile())
+	pluginData, err := requests.GetPluginData(ctx, baseURL, stripe.APIVersion, apiKey, cfg.GetProfile())
 
 	if err != nil {
-		ansi.StopSpinner(spinner, ansi.Faint(fmt.Sprintf("could not install plugin '%s': unauthorized", p.Shortname)), os.Stdout)
-		return err
+		ansi.StopSpinner(spinner, ansi.Faint(fmt.Sprintf("could not install plugin '%s'", p.Shortname)), os.Stdout)
+
+		log.WithFields(log.Fields{
+			"prefix": "plugins.plugin.Install",
+		}).Debugf("install error: %s", err)
+
+		return errors.New("you don't seem to have access to this plugin")
 	}
 
 	pluginDownloadURL := fmt.Sprintf("%s/%s/%s/%s/%s/%s", pluginData.PluginBaseURL, p.Shortname, version, runtime.GOOS, runtime.GOARCH, p.Binary)
 
 	// Pull down bin, verify, and save to disk
-	err = p.downloadAndSavePlugin(config, pluginDownloadURL, fs, version)
+	err = p.downloadAndSavePlugin(cfg, pluginDownloadURL, fs, version)
 
 	if err != nil {
-		ansi.StopSpinner(spinner, ansi.Faint(fmt.Sprintf("could not install plugin '%s'", p.Shortname)), os.Stdout)
+		ansi.StopSpinner(spinner, ansi.Faint(fmt.Sprintf("could not install plugin '%s': %s", p.Shortname, err)), os.Stdout)
+		return err
+	}
+
+	profile := cfg.GetProfile()
+	installedList := profile.GetInstalledPlugins()
+
+	// check for plugin already in list (ie. in the case of an upgrade)
+	isInstalled := false
+	for _, name := range installedList {
+		if name == p.Shortname {
+			isInstalled = true
+		}
+	}
+
+	if !isInstalled {
+		installedList = append(installedList, p.Shortname)
+	}
+
+	// sync list of installed plugins to file
+	cfg.WriteConfigField("installed_plugins", installedList)
+
+	if err != nil {
+		ansi.StopSpinner(spinner, ansi.Faint(fmt.Sprintf("could not install plugin '%s', %s", p.Shortname, err)), os.Stdout)
 		return err
 	}
 
 	// Once the plugin is successfully downloaded, clean up other versions
-	p.cleanUpPluginPath(config, fs, version)
+	p.cleanUpPluginPath(cfg, fs, version)
 
-	ansi.StopSpinner(spinner, ansi.Faint(""), os.Stdout)
+	ansi.StopSpinner(spinner, "", os.Stdout)
 
 	return nil
 }
