@@ -5,6 +5,7 @@ import (
 	"fmt"
 	"io/ioutil"
 	"net/http"
+	"net/http/httptrace"
 	"os"
 	"path/filepath"
 
@@ -14,6 +15,7 @@ import (
 
 	hcplugin "github.com/hashicorp/go-plugin"
 	"github.com/spf13/afero"
+	"github.com/spf13/cobra"
 
 	"github.com/stripe/stripe-cli/pkg/config"
 	"github.com/stripe/stripe-cli/pkg/requests"
@@ -116,19 +118,25 @@ func RefreshPluginManifest(ctx context.Context, config config.IConfig, fs afero.
 
 // FetchRemoteResource returns the remote resource body
 func FetchRemoteResource(url string) ([]byte, error) {
-	client := http.Client{
-		CheckRedirect: func(r *http.Request, via []*http.Request) error {
-			r.URL.Opaque = r.URL.Path
-			return nil
-		},
-	}
+	t := &requests.TracedTransport{}
+
+	req, err := http.NewRequest("GET", url, nil)
 
-	req, err := http.NewRequest(http.MethodGet, url, http.NoBody)
 	if err != nil {
 		return nil, err
 	}
 
+	trace := &httptrace.ClientTrace{
+		GotConn: t.GotConn,
+		DNSDone: t.DNSDone,
+	}
+
+	req = req.WithContext(httptrace.WithClientTrace(req.Context(), trace))
+
+	client := &http.Client{Transport: t}
+
 	resp, err := client.Do(req)
+
 	if err != nil {
 		return nil, err
 	}
@@ -149,3 +157,17 @@ func CleanupAllClients() {
 	log.Debug("Tearing down plugin before exit")
 	hcplugin.CleanupClients()
 }
+
+// IsPluginCommand returns true if the command invoked is for a plugin
+// false otherwise
+func IsPluginCommand(cmd *cobra.Command) bool {
+	isPlugin := false
+
+	for key, value := range cmd.Annotations {
+		if key == "scope" && value == "plugin" {
+			isPlugin = true
+		}
+	}
+
+	return isPlugin
+}
